pub struct Database { /* private fields */ }Expand description
The process-wide managed database capability.
Implementations
Sourceimpl Database
impl Database
Sourcepub async fn connect(config: DatabaseConfig, observer: Observer) -> Result<Self>
pub async fn connect(config: DatabaseConfig, observer: Observer) -> Result<Self>
Creates the single managed pool and verifies that it can connect.
pub async fn query_all( &self, parent: &CallContext, statement: Statement, ) -> Result<Vec<DbRow>>
pub async fn query_optional( &self, parent: &CallContext, statement: Statement, ) -> Result<Option<DbRow>>
pub async fn write( &self, parent: &CallContext, statement: Statement, ) -> Result<WriteResult>
Sourcepub async fn transaction<T, F>(
&self,
parent: &CallContext,
operation: impl Into<OperationId>,
work: F,
) -> Result<T>
pub async fn transaction<T, F>( &self, parent: &CallContext, operation: impl Into<OperationId>, work: F, ) -> Result<T>
Runs one explicit, single-level transaction.
The callback returns a boxed async block because that is the minimal Rust API that safely ties all operations to the borrowed transaction.